Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(847)

Unified Diff: chrome/browser/extensions/display_info_provider_chromeos_unittest.cc

Issue 2906803002: Rename MaximizeMode to TabletMode (Closed)
Patch Set: updated filter Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/display_info_provider_chromeos_unittest.cc
diff --git a/chrome/browser/extensions/display_info_provider_chromeos_unittest.cc b/chrome/browser/extensions/display_info_provider_chromeos_unittest.cc
index f4998a6570a46fb7ed2a52110b4a552e2a4f8f86..96add5c56e1b57e50ffbb4b58e20adde0192a687 100644
--- a/chrome/browser/extensions/display_info_provider_chromeos_unittest.cc
+++ b/chrome/browser/extensions/display_info_provider_chromeos_unittest.cc
@@ -10,7 +10,7 @@
#include "ash/shell.h"
#include "ash/test/ash_test_base.h"
#include "ash/test/screen_orientation_controller_test_api.h"
-#include "ash/wm/maximize_mode/maximize_mode_controller.h"
+#include "ash/wm/tablet_mode/tablet_mode_controller.h"
#include "base/command_line.h"
#include "base/macros.h"
#include "base/strings/string_number_conversions.h"
@@ -31,10 +31,9 @@ namespace {
using DisplayUnitInfoList = DisplayInfoProvider::DisplayUnitInfoList;
using DisplayLayoutList = DisplayInfoProvider::DisplayLayoutList;
-void EnableMaximizeMode(bool enable) {
- ash::Shell::Get()
- ->maximize_mode_controller()
- ->EnableMaximizeModeWindowManager(enable);
+void EnableTabletMode(bool enable) {
+ ash::Shell::Get()->tablet_mode_controller()->EnableTabletModeWindowManager(
+ enable);
}
class DisplayInfoProviderChromeosTest : public ash::test::AshTestBase {
@@ -1024,9 +1023,9 @@ TEST_F(DisplayInfoProviderChromeosTest, SetRotation) {
secondary.id());
}
-// Tests that rotation changes made before entering maximize mode are restored
-// upon exiting maximize mode, and that a rotation lock is not set.
-TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeMaximizeMode) {
+// Tests that rotation changes made before entering tablet mode are restored
+// upon exiting tablet mode, and that a rotation lock is not set.
+TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeTabletMode) {
ash::ScreenOrientationController* screen_orientation_controller =
ash::Shell::Get()->screen_orientation_controller();
api::system_display::DisplayProperties info;
@@ -1042,10 +1041,10 @@ TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeMaximizeMode) {
EXPECT_TRUE(error.empty());
EXPECT_FALSE(screen_orientation_controller->rotation_locked());
- // Entering maximize mode enables accelerometer screen rotations.
- EnableMaximizeMode(true);
+ // Entering tablet mode enables accelerometer screen rotations.
+ EnableTabletMode(true);
// Rotation lock should not activate because DisplayInfoProvider::SetInfo()
// was called when not in maximize mode.
EXPECT_FALSE(screen_orientation_controller->rotation_locked());
// ScreenOrientationController rotations override display info.
@@ -1055,16 +1054,16 @@ TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeMaximizeMode) {
display::Display::ROTATION_SOURCE_ACTIVE);
EXPECT_EQ(display::Display::ROTATE_0, GetCurrentInternalDisplayRotation());
- // Exiting maximize mode should restore the initial rotation
- EnableMaximizeMode(false);
+ // Exiting tablet mode should restore the initial rotation
+ EnableTabletMode(false);
EXPECT_EQ(display::Display::ROTATE_90, GetCurrentInternalDisplayRotation());
}
// Tests that rotation changes made during maximize mode lock the display
// against accelerometer rotations, and is set as user rotation locked.
-TEST_F(DisplayInfoProviderChromeosTest, SetRotationDuringMaximizeMode) {
- // Entering maximize mode enables accelerometer screen rotations.
- EnableMaximizeMode(true);
+TEST_F(DisplayInfoProviderChromeosTest, SetRotationDuringTabletMode) {
+ // Entering tablet mode enables accelerometer screen rotations.
+ EnableTabletMode(true);
ASSERT_FALSE(
ash::Shell::Get()->screen_orientation_controller()->rotation_locked());
@@ -1042,10 +1041,10 @@ TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeMaximizeMode) {
// Rotation lock should not activate because DisplayInfoProvider::SetInfo()
- // was called when not in maximize mode.
+ // was called when not in tablet mode.
EXPECT_FALSE(screen_orientation_controller->rotation_locked());
// ScreenOrientationController rotations override display info.
@@ -1055,16 +1054,16 @@ TEST_F(DisplayInfoProviderChromeosTest, SetRotationBeforeMaximizeMode) {
EXPECT_EQ(display::Display::ROTATE_90, GetCurrentInternalDisplayRotation());
}
-// Tests that rotation changes made during maximize mode lock the display
+// Tests that rotation changes made during tablet mode lock the display
// against accelerometer rotations, and is set as user rotation locked.

Powered by Google App Engine
This is Rietveld 408576698